@@ -277,15 +277,16 @@ Summarise <- function(condition, results, fixed_objects) NULL
 # print(SimDesign::main)
 #
 # }
-mainsim <- function(index, condition, generate, analyse, fixed_objects, max_errors, save_results_out_rootdir,
+mainsim <- function(index, condition, condition.row, generate, analyse, fixed_objects, max_errors, save_results_out_rootdir,
                     save, allow_na, allow_nan, save_seeds, save_seeds_dirname, load_seed, max_time, max_time.start,
                     warnings_as_errors, store_Random.seeds, store_warning_seeds, use_try, include_replication_index,
-                    useGenerate, useAnalyseHandler, p = NULL, future = FALSE, allow_gen_errors = TRUE){
+                    useGenerate, useAnalyseHandler, logging, p = NULL, future = FALSE, allow_gen_errors = TRUE){
 
     if(!is.null(p)) p(sprintf("replication = %g", index))
     if(include_replication_index) condition$REPLICATION <- index
     try_error <- try_error_seeds <- warning_message_seeds <- NULL
 
+    generate_time <- analyse_time <- 0
     while(TRUE){
 
         Warnings <- NULL
@@ -307,6 +308,7 @@ mainsim <- function(index, condition, generate, analyse, fixed_objects, max_erro
         }
         if(!is.null(load_seed))
             .GlobalEnv$.Random.seed <- load_seed
+        start_time <- proc.time()[3L]
         simlist <- if(useGenerate){
             if(allow_gen_errors)
                 try(withCallingHandlers(generate(condition=condition,
@@ -337,6 +339,9 @@ mainsim <- function(index, condition, generate, analyse, fixed_objects, max_erro
             try_error_seeds <- rbind(try_error_seeds, current_Random.seed)
             next
         }
+        end_time <- proc.time()[3L]
+        generate_time <- generate_time + (end_time - start_time)
+        start_time <- end_time
         res <- if(useAnalyseHandler)
             try(withCallingHandlers(analyse(dat=simlist, condition=condition,
                                fixed_objects=fixed_objects), warning=wHandler), silent=TRUE)
@@ -344,6 +349,8 @@ mainsim <- function(index, condition, generate, analyse, fixed_objects, max_erro
                          fixed_objects=fixed_objects), silent=TRUE)
         if(!valid_results(res))
             stop("Invalid object returned from Analyse()", call.=FALSE)
+        end_time <- proc.time()[3L]
+        analyse_time <- analyse_time + (end_time - start_time)
         if(!use_try){
             if(is(res, 'try-error')){
                 debug(analyse)
@@ -389,7 +396,7 @@ mainsim <- function(index, condition, generate, analyse, fixed_objects, max_erro
                             call.=FALSE), silent=TRUE)
         }
 
-        # if an error was detected in compute(), try again
+        # if an error was detected in analyse(), try again
         if(is(res, 'try-error')){
             res[1L] <-
                 gsub('Error in analyse\\(dat = simlist, condition = condition, fixed_objects = fixed_objects) : \\n  ',
@@ -417,6 +424,13 @@ mainsim <- function(index, condition, generate, analyse, fixed_objects, max_erro
             rownames(warning_message_seeds) <- Warnings
         if(store_Random.seeds)
             attr(res, 'current_Random.seed') <- current_Random.seed
+        attr(res, 'generate_analyse_time') <-
+            unname(c(generate_time, analyse_time))
+        if(logging == 'verbose')
+            cat(sprintf("\nDesign row: %s, Replication: %i \n Time: generate = %s, analyse = %s",
+                condition.row, index,
+                timeFormater(generate_time, output='SBATCH', input='sec'),
+                timeFormater(analyse_time, output='SBATCH', input='sec')))
         attr(res, 'try_errors') <- try_error
         attr(res, 'try_error_seeds') <- try_error_seeds
         attr(res, 'warnings') <- Warnings
@@ -428,6 +442,11 @@ mainsim <- function(index, condition, generate, analyse, fixed_objects, max_erro
 mainsim_maxtime <- function(max_time, max_time.start, ...){
     st <- proc.time()['elapsed']
     time_left <- max_time - (st - max_time.start)
+    if(time_left <= 0){
+        out <- NA
+        class(out) <- 'timed_out'
+        return(out)
+    }
     out <- R.utils::withTimeout(mainsim(...),
                                 timeout = time_left,
                                 onTimeout = 'warning')
